@@ -346,13 +346,6 @@ sub run {
         croak "At ", join( '/', $self->path ), " with arguments [@$arguments]: $@";
     }
 
-    my $at_end = ! @$arguments;
-
-    unless ($at_end || $control->{always_run}) {
-        warn "Context::Step::run ", $self->context->path_as_string, " SKIP\n" if DEBUG;
-        return;
-    }
-
     $self->context->_remaining_arguments( $arguments );
 
     while (my ($key, $value) = each %$options) {
@@ -360,6 +353,13 @@ sub run {
         $self->context->option( $key => $value ); # TODO Better way to do this...
     }
 
+    my $last = ! @$arguments;
+
+    unless ($last) {
+        warn "Context::Step::run ", $self->context->path_as_string, " SKIP\n" if DEBUG;
+        return;
+    }
+
     my $run = $self->_run;
     $run->( $self->context, @$arguments ) if $run;
 
